diff --git a/db_qbe.php b/db_qbe.php
index 0f5d9054f1..258182af1c 100644
--- a/db_qbe.php
+++ b/db_qbe.php
@@ -140,32 +140,65 @@ $realwidth = $form_column_width . 'ex';
*/
/**
- * Enter description here...
+ * Provides select options list containing column names
*
* @param array $columns
* @param integer $column_number
* @param string $selected
*/
function showColumnSelectCell($columns, $column_number, $selected = '')
{
- ?>
-
- |
- ';
+ $html_output .= '';
+ return $html_output;
+}
+
+/**
+ * Provides search form's row containing column select options
+ *
+ * @param array $criteria_column_count
+ * @param integer $columns
+ * @param string $ins_col
+ * @param string $del_col
+ *
+ * @return HTML for search table's roe
+ */
+function PMA_dbQbegetColumnNamesRow(
+ $criteria_column_count, $columns, $ins_col = null, $del_col = null
+) {
+ $html_output = '';
+ $html_output .= '| ' . __('Column') . ': | ';
+ $z = 0;
+ for ($column_index = 0; $column_index < $criteria_column_count; $column_index++)
+ {
+ if (isset($ins_col[$column_index]) && $ins_col[$column_index] == 'on') {
+ $html_output .= showColumnSelectCell($columns, $z);
+ $z++;
+ }
+ if (! empty($del_col) && isset($del_col[$column_index]) && $del_col[$column_index] == 'on') {
+ continue;
+ }
+ $selected = '';
+ if (isset($_REQUEST['Field'][$column_index])) {
+ $selected = $_REQUEST['Field'][$column_index];
+ $curField[$z] = $_REQUEST['Field'][$column_index];
+ }
+ $html_output .= showColumnSelectCell($columns, $z, $selected);
+ $z++;
+ } // end for
+ $html_output .= '
';
+ return $html_output;
}
if ($cfgRelation['designerwork']) {
@@ -187,30 +220,11 @@ if ($cfgRelation['designerwork']) {
@@ -140,32 +140,65 @@ $realwidth = $form_column_width . 'ex';
*
- * @param array $columns
- * @param integer $column_number
- * @param string $selected
+ * @param array $columns All Column Names
+ * @param integer $column_number Column Number (0,1,2) or more
+ * @param string $selected Selected criteria column name
+ *
+ * @return HTML for select options
*/
function showColumnSelectCell($columns, $column_number, $selected = '')